Learn R Programming

rgeopat2 (version 0.4.0)

rgeopat2-package: rgeopat2: Additional Functions for 'GeoPAT' 2

Description

Supports analysis of spatial data processed with the 'GeoPAT' 2 software https://github.com/Nowosad/geopat2. Available features include creation of a grid based on the 'GeoPAT' 2 grid header file and reading a 'GeoPAT' 2 text outputs.

Arguments

Author

Maintainer: Jakub Nowosad nowosad.jakub@gmail.com (ORCID)

Other contributors:

  • Space Informatics Lab [copyright holder]

See Also